Index: /extensions/Piwecard/language/sk_SK/plugin.lang.php
===================================================================
--- /extensions/Piwecard/language/sk_SK/plugin.lang.php	(revision 20091)
+++ /extensions/Piwecard/language/sk_SK/plugin.lang.php	(revision 20092)
@@ -1,5 +1,5 @@
 <?php
 /*
- * Plugin Name: Piwecard
+ * Plugin Name: Piwpiwecard
  * File :  plugin.lang.php
 * Lang : SK
@@ -7,74 +7,74 @@
 
 
-$lang['ecard']							= 'Piwepohľadnica';
-$lang['ecard_infos']	 				= 'Detail ePohľadnice';
-$lang['ecard_from']						= 'Od';
-$lang['ecard_to']						= 'Pre';
+$lang['piwecard']							= 'Piwepohľadnica';
+$lang['piwecard_infos']	 				= 'Detail ePohľadnice';
+$lang['piwecard_from']						= 'Od';
+$lang['piwecard_to']						= 'Pre';
 
 
 
 // ecart.tpl
-$lang['ecard_send']						= 'Poslať';
-$lang['ecard_cancel']					= 'Zrušiť';
-$lang['ecard_activ_choice']				= 'Platnosť';
-$lang['ecard_send_method']				= 'Metóda poslania';
-$lang['ecard_maillink']					= 'Mail s linkom';
-$lang['ecard_mailhtml']					= 'Úplný mail s fotkou';
-$lang['ecard_send_copy']				= 'Prijať kópiu';
+$lang['piwecard_send']						= 'Poslať';
+$lang['piwecard_cancel']					= 'Zrušiť';
+$lang['piwecard_activ_choice']				= 'Platnosť';
+$lang['piwecard_send_method']				= 'Metóda poslania';
+$lang['piwecard_maillink']					= 'Mail s linkom';
+$lang['piwecard_mailhtml']					= 'Úplný mail s fotkou';
+$lang['piwecard_send_copy']				= 'Prijať kópiu';
 
 
-$lang['ecard_send_stage1']				= 'Fáza 1: Napísať Vašu správu';
-$lang['ecard_send_stage2']				= 'Fáza 2: Upraviť informácie';
-$lang['ecard_send_stage3']				= 'Fáza 3: Voľby';
-$lang['ecard_send_stage4']				= 'Fáza 4: Poslať ePohľadnicu!';
+$lang['piwecard_send_stage1']				= 'Fáza 1: Napísať Vašu správu';
+$lang['piwecard_send_stage2']				= 'Fáza 2: Upraviť informácie';
+$lang['piwecard_send_stage3']				= 'Fáza 3: Voľby';
+$lang['piwecard_send_stage4']				= 'Fáza 4: Poslať ePohľadnicu!';
 
-$lang['ecard_send_title']				= 'Názov ePohľadnice ';
-$lang['ecard_send_message']				= 'Správa ePohľadnice';
-$lang['ecard_send_exp']					= 'Odosielateľ';
-$lang['ecard_send_dest']				= 'Prijímateľ';
-$lang['ecard_send_link1']				= 'Poslať ePohľadnicu';
-$lang['ecard_send_link2']				= 'Sem kliknúť';
-$lang['ecard_send_link3']				= 'Vytvoriť Vašu osobnú ePohľadnicu';
+$lang['piwecard_send_title']				= 'Názov ePohľadnice ';
+$lang['piwecard_send_message']				= 'Správa ePohľadnice';
+$lang['piwecard_send_exp']					= 'Odosielateľ';
+$lang['piwecard_send_dest']				= 'Prijímateľ';
+$lang['piwecard_send_link1']				= 'Poslať ePohľadnicu';
+$lang['piwecard_send_link2']				= 'Sem kliknúť';
+$lang['piwecard_send_link3']				= 'Vytvoriť Vašu osobnú ePohľadnicu';
 
-$lang['ecard_send_exp_name']			= 'Meno odosielateľa';
-$lang['ecard_send_exp_mail']			= 'Mail odosielateľa';
-$lang['ecard_send_dest_name']			= 'Meno prijímateľa';
-$lang['ecard_send_dest_mail']			= 'Mail prijímateľa (dest@dest.com)';
+$lang['piwecard_send_exp_name']			= 'Meno odosielateľa';
+$lang['piwecard_send_exp_mail']			= 'Mail odosielateľa';
+$lang['piwecard_send_dest_name']			= 'Meno prijímateľa';
+$lang['piwecard_send_dest_mail']			= 'Mail prijímateľa (dest@dest.com)';
 
 
 // publish.tpl
-$lang['ecard_invalid_ecard']			= 'Neplatná alebo stará ePohľadnica';
-$lang['ecard_publish_bottom']			= 'Táto ePohľadnica bola poslaná ';
+$lang['piwecard_invalid_piwecard']			= 'Neplatná alebo stará ePohľadnica';
+$lang['piwecard_publish_bottom']			= 'Táto ePohľadnica bola poslaná ';
 
 // Admin
-$lang['ecard_admin_saveOK']				= 'Konfigurácia uložená';
+$lang['piwecard_admin_saveOK']				= 'Konfigurácia uložená';
 
-$lang['ecard_management']				= 'Ovládanie Piwepohľadnice';
-$lang['ecard_manage']					= 'Parametre pre túto funkciu v galérii';
-$lang['ecard_active_user_cat']			= 'Aktivovať túto funkciu len pre používateľov alebo kategórie patriace používateľom (založené autorom alebo názvom kategórie)';
-$lang['ecard_active_spec_cats']			= 'Aktivovať túto funkciu pre označené kategórie';
-$lang['ecard_active_all_cats']			= 'Aktivovať túto funkciu pre všetky kategórie';
-$lang['ecard_recursiv']					= 'Aktivovať rekurzívne';
-$lang['ecard_cat']						= 'Vybrať kategórie (Len ak "všetky kategórie" sú neoznačené)';
-$lang['ecard_authorized_group']			= 'Skupinové parametre'; 
-$lang['ecard_authorized_group_info']	= 'Neoznačené ==> Povoliť pre všetkých používateľov'; 
-$lang['ecard_admin_manage']					= 'Výber';
+$lang['piwecard_management']				= 'Ovládanie Piwepohľadnice';
+$lang['piwecard_manage']					= 'Parametre pre túto funkciu v galérii';
+$lang['piwecard_active_user_cat']			= 'Aktivovať túto funkciu len pre používateľov alebo kategórie patriace používateľom (založené autorom alebo názvom kategórie)';
+$lang['piwecard_active_spec_cats']			= 'Aktivovať túto funkciu pre označené kategórie';
+$lang['piwecard_active_all_cats']			= 'Aktivovať túto funkciu pre všetky kategórie';
+$lang['piwecard_recursiv']					= 'Aktivovať rekurzívne';
+$lang['piwecard_cat']						= 'Vybrať kategórie (Len ak "všetky kategórie" sú neoznačené)';
+$lang['piwecard_authorized_group']			= 'Skupinové parametre'; 
+$lang['piwecard_authorized_group_info']	= 'Neoznačené ==> Povoliť pre všetkých používateľov'; 
+$lang['piwecard_admin_manage']					= 'Výber';
 
-$lang['ecard_admin_params']					= 'Parametre';
-$lang['ecard_config']					= 'Štandardná konfigurácia';
+$lang['piwecard_admin_params']					= 'Parametre';
+$lang['piwecard_config']					= 'Štandardná konfigurácia';
 
-$lang['ecard_activ_nb']					= 'Počet dní (predvolené) pre platnosť ePohľadnice';
-$lang['ecard_days']						= 'dní';
-$lang['ecard_nolimit']					= 'Neobmedzené';
+$lang['piwecard_activ_nb']					= 'Počet dní (predvolené) pre platnosť ePohľadnice';
+$lang['piwecard_days']						= 'dní';
+$lang['piwecard_nolimit']					= 'Neobmedzené';
 
-$lang['ecard_nomodif_expmail']			= 'Povoliť mail odosielateľa zmeniť používateľom';
-$lang['ecard_send_HTML']				= 'Povoliť mail odosielateľa s fotkou (inak je poslaný len link)';
-$lang['ecard_show_infos']				= 'Zobraziť informácie pod fotografiami (meno a autor)';
-$lang['ecard_admin_nb_page']			= 'Počet ePohľadníc v zozname';
-$lang['ecard_mail_config']				= 'Parameter pre poslanie mailu';
-$lang['ecard_subject_link']				= 'Predmet mailu';
-$lang['ecard_message_link']				= 'Poslať správu (mail len pre mód linku)';
-$lang['ecard_message_html']				= 'Poslať správu (mail HTML s fotkou)';
-$lang['ecard_parameters']			= 
+$lang['piwecard_nomodif_expmail']			= 'Povoliť mail odosielateľa zmeniť používateľom';
+$lang['piwecard_send_HTML']				= 'Povoliť mail odosielateľa s fotkou (inak je poslaný len link)';
+$lang['piwecard_show_infos']				= 'Zobraziť informácie pod fotografiami (meno a autor)';
+$lang['piwecard_admin_nb_page']			= 'Počet ePohľadníc v zozname';
+$lang['piwecard_mail_config']				= 'Parameter pre poslanie mailu';
+$lang['piwecard_subject_link']				= 'Predmet mailu';
+$lang['piwecard_message_link']				= 'Poslať správu (mail len pre mód linku)';
+$lang['piwecard_message_html']				= 'Poslať správu (mail HTML s fotkou)';
+$lang['piwecard_parameters']			= 
 '<b><u>Parametre </u></b>:<br> 
 <b>%yourname%</b>    ==> Meno odosielateľa<br>
@@ -84,22 +84,22 @@
 <b>%website%</b>        ==> Meno stránky (Piwigo štandardná konfigurácia)<br>
 <b>%websiteurl%</b>    ==> Link na stránku (Piwigo štandardná konfigurácia)<br>
-<b>%ecardurl%</b>      ==> Link na stránku ePohľadnice<br>
-<b>%ecardsubject%</b>       ==> Predmet ePohľadnice (napísané používateľom)<br>
-<b>%ecardmessage%</b>     ==> Správa ePohľadnice (napísané používateľom)<br>
+<b>%piwecardurl%</b>      ==> Link na stránku ePohľadnice<br>
+<b>%piwecardsubject%</b>       ==> Predmet ePohľadnice (napísané používateľom)<br>
+<b>%piwecardmessage%</b>     ==> Správa ePohľadnice (napísané používateľom)<br>
 <b>%pictureurl%</b>      ==> Link na fotku<br>
 <b>%pictureinfos%</b>    ==> Informácie o fotke (názov a autor)';
 
-$lang['ecard_admin_consult']					= 'Zoznam';
-$lang['ecard_consult_detail']			= 'Zoznam ePohľadníc';
-$lang['ecard_list']						= 'Zoznam odoslaných ePohľadníc';
-$lang['ecard_delete_all']				= 'Vymazať všetky staré ePohľadníce?';
+$lang['piwecard_admin_consult']					= 'Zoznam';
+$lang['piwecard_consult_detail']			= 'Zoznam ePohľadníc';
+$lang['piwecard_list']						= 'Zoznam odoslaných ePohľadníc';
+$lang['piwecard_delete_all']				= 'Vymazať všetky staré ePohľadníce?';
 $lang['valid']							= 'Platné';
 $lang['total']							= 'Spolu';
-$lang['ecard_force_delete']				= 'Vymazať (nasilu) túto ePohľadnícu?';
-$lang['ecard_delete']					= 'Vymazať túto ePohľadnícu?';
+$lang['piwecard_force_delete']				= 'Vymazať (nasilu) túto ePohľadnícu?';
+$lang['piwecard_delete']					= 'Vymazať túto ePohľadnícu?';
 
-$lang['ecard_admin_submit']				= 'Uložiť';
+$lang['piwecard_admin_submit']				= 'Uložiť';
 
-$lang['ecard_default_mail']				= 'Prednastavený mail pre ePohľadnice hostí';
+$lang['piwecard_default_mail']				= 'Prednastavený mail pre ePohľadnice hostí';
 
 
Index: /extensions/Piwecard/language/tr_TR/plugin.lang.php
===================================================================
--- /extensions/Piwecard/language/tr_TR/plugin.lang.php	(revision 20091)
+++ /extensions/Piwecard/language/tr_TR/plugin.lang.php	(revision 20092)
@@ -21,72 +21,72 @@
 // | USA.                                                                  |
 // +-----------------------------------------------------------------------+
-$lang['ecard_admin_saveOK'] = 'Ayarlar kaydedildi';
-$lang['ecard_error'] = 'Hata!';
-$lang['ecard_error_email'] = 'Hatalı e-posta.';
-$lang['ecard_admin_submit'] = 'Kaydet';
-$lang['ecard_cancel'] = 'İptal Et';
-$lang['ecard_days'] = 'gün';
-$lang['ecard_activ_nb'] = 'e-Kartın varsayılan geçerlilik gün sayısı';
-$lang['ecard_active_user_cat'] = 'Bu fonksiyonu sadece kullanıcılara veya kullanıcılara bağlı kategoriler için etkinleştirin (yazar veya kategori adına dayalı)';
-$lang['ecard_recursiv'] = 'Yinelemeyi etkinleştir';
-$lang['ecard_cat'] = 'Kategorileri seç (eğer "tüm kategoriler" seçilmemişse)';
+$lang['piwecard_admin_saveOK'] = 'Ayarlar kaydedildi';
+$lang['piwecard_error'] = 'Hata!';
+$lang['piwecard_error_email'] = 'Hatalı e-posta.';
+$lang['piwecard_admin_submit'] = 'Kaydet';
+$lang['piwecard_cancel'] = 'İptal Et';
+$lang['piwecard_days'] = 'gün';
+$lang['piwecard_activ_nb'] = 'e-Kartın varsayılan geçerlilik gün sayısı';
+$lang['piwecard_active_user_cat'] = 'Bu fonksiyonu sadece kullanıcılara veya kullanıcılara bağlı kategoriler için etkinleştirin (yazar veya kategori adına dayalı)';
+$lang['piwecard_recursiv'] = 'Yinelemeyi etkinleştir';
+$lang['piwecard_cat'] = 'Kategorileri seç (eğer "tüm kategoriler" seçilmemişse)';
 $lang['valid'] = 'Geçerli';
 $lang['total'] = 'Toplam';
-$lang['ecard_send_link1'] = 'Bir e-Kart göndermek için';
+$lang['piwecard_send_link1'] = 'Bir e-Kart göndermek için';
 $lang['selected_cats'] = 'Seçili kategoriler';
 $lang['non_selected_cats'] = 'Seçili kategori yok';
-$lang['ecard_validity_label'] = 'Geçerlilik';
-$lang['ecard_to'] = 'Kime';
-$lang['ecard_subject_link'] = 'Posta konusu';
-$lang['ecard_show_infos'] = 'Fotoğrafların altında bilgileri göster (isim ve eser sahibi)';
-$lang['ecard_send_title'] = 'e-Kart Başlığı';
-$lang['ecard_send_stage1'] = '1.Aşama: Mesajınızı yazın';
-$lang['ecard_send_stage2'] = '2.Aşama: Bilgileri düzenleyin';
-$lang['ecard_send_stage3'] = '3.Aşama: Seçenekleri belirleyin';
-$lang['ecard_send_stage4'] = '4.Aşama: e-Kartı gönderin!';
-$lang['ecard_send_method'] = 'Gönderim şekli';
-$lang['ecard_send_message'] = 'e-Kart Mesajı';
-$lang['ecard_send_mandatory_fields'] = 'Zorunlu alanlar';
-$lang['ecard_send_link3'] = 'Kişiselleştirdiğiniz e-Kartınız hazırlanıyor';
-$lang['ecard_send_link2'] = 'Buraya tıklayın';
-$lang['ecard_nomodif_expmail'] = 'Kullanıcının gönderilecek e-Postayı düzenlemesine izin ver.';
-$lang['ecard_send_exp_mail'] = 'Gönderenin e-posta adresi';
-$lang['ecard_send_exp_name'] = 'Gönderenin Adı';
-$lang['ecard_send_exp'] = 'Gönderen';
-$lang['ecard_send_dest_name'] = 'Alıcı Adı';
-$lang['ecard_send_dest_mail'] = 'Alıcı e-posta adresi (Örn: dest@dest.com)';
-$lang['ecard_send_dest'] = 'Alıcı';
-$lang['ecard_parameters'] = 'Parametreler';
-$lang['ecard_publish_bottom'] = 'e-Kart bu kişi tarafından gönderildi:';
-$lang['ecard_nolimit'] = 'Limitsiz';
-$lang['ecard_message_link'] = 'Mesaj gönderildi (sadece fotoğraf bağlantısı içeren modda)';
-$lang['ecard_message_html'] = 'Mesaj gönderildi (fotoğraf içerikli HTML olarak)';
-$lang['ecard_management'] = 'Piwecard Yönetimi';
-$lang['ecard_manage'] = 'Galerideki bu fonksiyon için parametreler';
-$lang['ecard_mail_config'] = 'Gönderilen posta için parametre';
-$lang['ecard_mailhtml'] = 'Postayı resim ile tamamla';
-$lang['ecard_list'] = 'Gönderilen e-Kartların listesi';
-$lang['ecard_infos'] = 'e-Kart detayı';
-$lang['ecard_invalid_ecard'] = 'Geçersiz veya süresi biten e-Kart';
-$lang['ecard_send_HTML'] = 'Postanın resim ile gönderilmesine izin ver (diğer durumda sadece bağlantı gönderilir)';
-$lang['ecard_send_copy'] = 'Bir kopyasını al';
-$lang['ecard_send'] = 'Gönder';
-$lang['ecard_maillink'] = 'Bağlantı ile postala';
-$lang['ecard_default_mail'] = 'Misafir e-Kartları için varsayılan posta';
-$lang['ecard_from'] = 'Kimden';
-$lang['ecard_force_delete'] = 'Bu e-Kart silinsin (zorla) mi?';
-$lang['ecard_error_text'] = 'Alanları doldurun.';
-$lang['ecard_delete_all'] = 'Geçerliliği biten e-Kartlar silinsin mi?';
-$lang['ecard_delete'] = 'Bu e-Kart silinsin mi?';
-$lang['ecard_config'] = 'Standart yapılandırma';
-$lang['ecard_consult_detail'] = 'e-Kart Listesi';
-$lang['ecard_active_spec_cats'] = 'Bu fonksiyonu seçilen kategorilerde etkinleştir';
-$lang['ecard_active_all_cats'] = 'Bu fonksiyonu tüm kategorilerde etkinleştir';
-$lang['ecard_authorized_group_info'] = 'Hiçbiri kontrol edilmedi ==> Tüm kullanıcılara izin veriliyor';
-$lang['ecard_authorized_group'] = 'Grup parametreleri';
-$lang['ecard_admin_params'] = 'Parametreler';
-$lang['ecard_admin_nb_page'] = 'Liste sekmesindeki e-Kart sayısı';
-$lang['ecard_admin_consult'] = 'Liste';
-$lang['ecard_admin_manage'] = 'Seçim';
-$lang['ecard'] = 'Piwecard';
+$lang['piwecard_validity_label'] = 'Geçerlilik';
+$lang['piwecard_to'] = 'Kime';
+$lang['piwecard_subject_link'] = 'Posta konusu';
+$lang['piwecard_show_infos'] = 'Fotoğrafların altında bilgileri göster (isim ve eser sahibi)';
+$lang['piwecard_send_title'] = 'e-Kart Başlığı';
+$lang['piwecard_send_stage1'] = '1.Aşama: Mesajınızı yazın';
+$lang['piwecard_send_stage2'] = '2.Aşama: Bilgileri düzenleyin';
+$lang['piwecard_send_stage3'] = '3.Aşama: Seçenekleri belirleyin';
+$lang['piwecard_send_stage4'] = '4.Aşama: e-Kartı gönderin!';
+$lang['piwecard_send_method'] = 'Gönderim şekli';
+$lang['piwecard_send_message'] = 'e-Kart Mesajı';
+$lang['piwecard_send_mandatory_fields'] = 'Zorunlu alanlar';
+$lang['piwecard_send_link3'] = 'Kişiselleştirdiğiniz e-Kartınız hazırlanıyor';
+$lang['piwecard_send_link2'] = 'Buraya tıklayın';
+$lang['piwecard_nomodif_expmail'] = 'Kullanıcının gönderilecek e-Postayı düzenlemesine izin ver.';
+$lang['piwecard_send_exp_mail'] = 'Gönderenin e-posta adresi';
+$lang['piwecard_send_exp_name'] = 'Gönderenin Adı';
+$lang['piwecard_send_exp'] = 'Gönderen';
+$lang['piwecard_send_dest_name'] = 'Alıcı Adı';
+$lang['piwecard_send_dest_mail'] = 'Alıcı e-posta adresi (Örn: dest@dest.com)';
+$lang['piwecard_send_dest'] = 'Alıcı';
+$lang['piwecard_parameters'] = 'Parametreler';
+$lang['piwecard_publish_bottom'] = 'e-Kart bu kişi tarafından gönderildi:';
+$lang['piwecard_nolimit'] = 'Limitsiz';
+$lang['piwecard_message_link'] = 'Mesaj gönderildi (sadece fotoğraf bağlantısı içeren modda)';
+$lang['piwecard_message_html'] = 'Mesaj gönderildi (fotoğraf içerikli HTML olarak)';
+$lang['piwecard_management'] = 'Piwpiwecard Yönetimi';
+$lang['piwecard_manage'] = 'Galerideki bu fonksiyon için parametreler';
+$lang['piwecard_mail_config'] = 'Gönderilen posta için parametre';
+$lang['piwecard_mailhtml'] = 'Postayı resim ile tamamla';
+$lang['piwecard_list'] = 'Gönderilen e-Kartların listesi';
+$lang['piwecard_infos'] = 'e-Kart detayı';
+$lang['piwecard_invalid_piwecard'] = 'Geçersiz veya süresi biten e-Kart';
+$lang['piwecard_send_HTML'] = 'Postanın resim ile gönderilmesine izin ver (diğer durumda sadece bağlantı gönderilir)';
+$lang['piwecard_send_copy'] = 'Bir kopyasını al';
+$lang['piwecard_send'] = 'Gönder';
+$lang['piwecard_maillink'] = 'Bağlantı ile postala';
+$lang['piwecard_default_mail'] = 'Misafir e-Kartları için varsayılan posta';
+$lang['piwecard_from'] = 'Kimden';
+$lang['piwecard_force_delete'] = 'Bu e-Kart silinsin (zorla) mi?';
+$lang['piwecard_error_text'] = 'Alanları doldurun.';
+$lang['piwecard_delete_all'] = 'Geçerliliği biten e-Kartlar silinsin mi?';
+$lang['piwecard_delete'] = 'Bu e-Kart silinsin mi?';
+$lang['piwecard_config'] = 'Standart yapılandırma';
+$lang['piwecard_consult_detail'] = 'e-Kart Listesi';
+$lang['piwecard_active_spec_cats'] = 'Bu fonksiyonu seçilen kategorilerde etkinleştir';
+$lang['piwecard_active_all_cats'] = 'Bu fonksiyonu tüm kategorilerde etkinleştir';
+$lang['piwecard_authorized_group_info'] = 'Hiçbiri kontrol edilmedi ==> Tüm kullanıcılara izin veriliyor';
+$lang['piwecard_authorized_group'] = 'Grup parametreleri';
+$lang['piwecard_admin_params'] = 'Parametreler';
+$lang['piwecard_admin_nb_page'] = 'Liste sekmesindeki e-Kart sayısı';
+$lang['piwecard_admin_consult'] = 'Liste';
+$lang['piwecard_admin_manage'] = 'Seçim';
+$lang['piwecard'] = 'Piwpiwecard';
 ?>

Index: /extensions/Piwecard/language/ru_RU/plugin.lang.php
===================================================================
--- /extensions/Piwecard/language/ru_RU/plugin.lang.php	(revision 20091)
+++ /extensions/Piwecard/language/ru_RU/plugin.lang.php	(revision 20092)
@@ -1,5 +1,5 @@
 <?php
 /*
  * Plugin Name: Piwecard
  * File :  plugin.lang.php
 * Lang : RU
@@ -7,74 +7,74 @@
 
 
-$lang['ecard']                            = 'Piwecard';
-$lang['ecard_infos']                     = 'Подробно о eCard';
-$lang['ecard_from']                        = 'От кого';
-$lang['ecard_to']                        = 'Кому';
+$lang['piwecard']                            = 'Piwpiwecard';
+$lang['piwecard_infos']                     = 'Подробно о piwecard';
+$lang['piwecard_from']                        = 'От кого';
+$lang['piwecard_to']                        = 'Кому';
 
 
 
 // ecart.tpl
-$lang['ecard_send']                        = 'Отправить';
-$lang['ecard_cancel']                    = 'Отказаться';
-$lang['ecard_activ_choice']                = 'Срок годности';
-$lang['ecard_send_method']                = 'Как послать:';
-$lang['ecard_maillink']                    = 'Письмо с ссылкой';
-$lang['ecard_mailhtml']                    = 'Письмо с фотографией';
-$lang['ecard_send_copy']                = 'Получить копию';
+$lang['piwecard_send']                        = 'Отправить';
+$lang['piwecard_cancel']                    = 'Отказаться';
+$lang['piwecard_activ_choice']                = 'Срок годности';
+$lang['piwecard_send_method']                = 'Как послать:';
+$lang['piwecard_maillink']                    = 'Письмо с ссылкой';
+$lang['piwecard_mailhtml']                    = 'Письмо с фотографией';
+$lang['piwecard_send_copy']                = 'Получить копию';
 
 
-$lang['ecard_send_stage1']                = 'Шаг 1 : Напишите сообщение';
-$lang['ecard_send_stage2']                = 'Шаг 2 : Впишите данные';
-$lang['ecard_send_stage3']                = 'Шаг 3 : Выбирете';
-$lang['ecard_send_stage4']                = 'Шаг 4 : Послать открытку!';
+$lang['piwecard_send_stage1']                = 'Шаг 1 : Напишите сообщение';
+$lang['piwecard_send_stage2']                = 'Шаг 2 : Впишите данные';
+$lang['piwecard_send_stage3']                = 'Шаг 3 : Выбирете';
+$lang['piwecard_send_stage4']                = 'Шаг 4 : Послать открытку!';
 
-$lang['ecard_send_title']                = 'Заголовок открытки';
-$lang['ecard_send_message']                = 'Текст открытки';
-$lang['ecard_send_exp']                    = 'Отправитель';
-$lang['ecard_send_dest']                = 'Получатель';
-$lang['ecard_send_link1']                = 'Вы можете отправить эту фотографию как открытку,';
-$lang['ecard_send_link2']                = 'для этого кликните прям сейчас)';
-$lang['ecard_send_link3']                = 'Создать свою собственную открытку';
+$lang['piwecard_send_title']                = 'Заголовок открытки';
+$lang['piwecard_send_message']                = 'Текст открытки';
+$lang['piwecard_send_exp']                    = 'Отправитель';
+$lang['piwecard_send_dest']                = 'Получатель';
+$lang['piwecard_send_link1']                = 'Вы можете отправить эту фотографию как открытку,';
+$lang['piwecard_send_link2']                = 'для этого кликните прям сейчас)';
+$lang['piwecard_send_link3']                = 'Создать свою собственную открытку';
 
-$lang['ecard_send_exp_name']            = 'Имя отправителя';
-$lang['ecard_send_exp_mail']            = 'Почта отправителя';
-$lang['ecard_send_dest_name']            = 'Имя получателя';
-$lang['ecard_send_dest_mail']            = 'Почта получателя (dest@dest.com)';
+$lang['piwecard_send_exp_name']            = 'Имя отправителя';
+$lang['piwecard_send_exp_mail']            = 'Почта отправителя';
+$lang['piwecard_send_dest_name']            = 'Имя получателя';
+$lang['piwecard_send_dest_mail']            = 'Почта получателя (dest@dest.com)';
 
 
 // publish.tpl
-$lang['ecard_invalid_ecard']            = 'Срок хранения открытки закончился';
-$lang['ecard_publish_bottom']            = 'Эта открытка была послана ';
+$lang['piwecard_invalid_piwecard']            = 'Срок хранения открытки закончился';
+$lang['piwecard_publish_bottom']            = 'Эта открытка была послана ';
 
 // Admin
-$lang['ecard_admin_saveOK']                = 'Конфигурация схранена';
+$lang['piwecard_admin_saveOK']                = 'Конфигурация схранена';
 
-$lang['ecard_management']                = 'Управление Piwecard';
-$lang['ecard_manage']                    = 'Параметры для этой функции в галерее';
-$lang['ecard_active_user_cat']            = 'Активировать эту функцию только для пользователя, или категории, которой принадлежит пользователь (в основе - автор или название категории)';
-$lang['ecard_active_spec_cats']            = 'Активировать эту функцию для выбранных категорий';
-$lang['ecard_active_all_cats']            = 'Активировать эту функцию для всех категори';
-$lang['ecard_recursiv']                    = 'Активировать рекурсив';
-$lang['ecard_cat']                        = 'Выбирете категории (Только если не выбрано "все категории")';
-$lang['ecard_authorized_group']            = 'Параметры групп';
-$lang['ecard_authorized_group_info']    = 'Не отмечать ==> Доступно для всех пользователей';
-$lang['ecard_admin_manage']                    = 'Вариант';
+$lang['piwecard_management']                = 'Управление Piwpiwecard';
+$lang['piwecard_manage']                    = 'Параметры для этой функции в галерее';
+$lang['piwecard_active_user_cat']            = 'Активировать эту функцию только для пользователя, или категории, которой принадлежит пользователь (в основе - автор или название категории)';
+$lang['piwecard_active_spec_cats']            = 'Активировать эту функцию для выбранных категорий';
+$lang['piwecard_active_all_cats']            = 'Активировать эту функцию для всех категори';
+$lang['piwecard_recursiv']                    = 'Активировать рекурсив';
+$lang['piwecard_cat']                        = 'Выбирете категории (Только если не выбрано "все категории")';
+$lang['piwecard_authorized_group']            = 'Параметры групп';
+$lang['piwecard_authorized_group_info']    = 'Не отмечать ==> Доступно для всех пользователей';
+$lang['piwecard_admin_manage']                    = 'Вариант';
 
-$lang['ecard_admin_params']                    = 'Параметры';
-$lang['ecard_config']                    = 'Стандартная конфигурация';
+$lang['piwecard_admin_params']                    = 'Параметры';
+$lang['piwecard_config']                    = 'Стандартная конфигурация';
 
-$lang['ecard_activ_nb']                    = 'Срок хранения открытки на сайте (по умолчанию)';
-$lang['ecard_days']                        = 'дней';
-$lang['ecard_nolimit']                    = 'Вечно';
+$lang['piwecard_activ_nb']                    = 'Срок хранения открытки на сайте (по умолчанию)';
+$lang['piwecard_days']                        = 'дней';
+$lang['piwecard_nolimit']                    = 'Вечно';
 
-$lang['ecard_nomodif_expmail']            = 'Позволить пользователю изменять информацию об отправителе';
-$lang['ecard_send_HTML']                = 'Позволить отправлять открытку с фотографией (в другом случае - в письме будет послана только ссылка на открытку)';
-$lang['ecard_show_infos']                = 'Показать информацию под фотографией (название и автор)';
-$lang['ecard_admin_nb_page']            = 'Количество открыток в списке';
-$lang['ecard_mail_config']                = 'Параметры отправки открытки';
-$lang['ecard_subject_link']                = 'Заголовок письма';
-$lang['ecard_message_link']                = 'Сообщение отправлено (письмо с сылкой)';
-$lang['ecard_message_html']                = 'сообщение отправлено (письмо с фотографией)';
-$lang['ecard_parameters']            =
+$lang['piwecard_nomodif_expmail']            = 'Позволить пользователю изменять информацию об отправителе';
+$lang['piwecard_send_HTML']                = 'Позволить отправлять открытку с фотографией (в другом случае - в письме будет послана только ссылка на открытку)';
+$lang['piwecard_show_infos']                = 'Показать информацию под фотографией (название и автор)';
+$lang['piwecard_admin_nb_page']            = 'Количество открыток в списке';
+$lang['piwecard_mail_config']                = 'Параметры отправки открытки';
+$lang['piwecard_subject_link']                = 'Заголовок письма';
+$lang['piwecard_message_link']                = 'Сообщение отправлено (письмо с сылкой)';
+$lang['piwecard_message_html']                = 'сообщение отправлено (письмо с фотографией)';
+$lang['piwecard_parameters']            =
 '<b><u>Paramètres </u></b>:<br>
 <b>%yourname%</b>    ==> Имя оправителя<br>
@@ -84,21 +84,21 @@
 <b>%website%</b>        ==> Название сайта (стандартная конфигурация Piwigo)<br>
 <b>%websiteurl%</b>    ==> Ссылка на сайт (стандартная конфигурация Piwigo)<br>
-<b>%ecardurl%</b>      ==> Ссылка на страницу хранения открытки<br>
-<b>%ecardsubject%</b>       ==> Тема открытки (заполняется пользователем)<br>
-<b>%ecardmessage%</b>     ==> Сообщение открытки (заполняется пользователем)<br>
+<b>%piwecardurl%</b>      ==> Ссылка на страницу хранения открытки<br>
+<b>%piwecardsubject%</b>       ==> Тема открытки (заполняется пользователем)<br>
+<b>%piwecardmessage%</b>     ==> Сообщение открытки (заполняется пользователем)<br>
 <b>%pictureurl%</b>      ==> Ссылка на фотографию<br>
 <b>%pictureinfos%</b>    ==> Информация о фотографии (название и автор)';
 
-$lang['ecard_admin_consult']                    = 'Список';
-$lang['ecard_consult_detail']            = 'Список открыток';
-$lang['ecard_list']                        = 'Посланные открытки';
-$lang['ecard_delete_all']                = 'Удалить все просроченные открытки?';
+$lang['piwecard_admin_consult']                    = 'Список';
+$lang['piwecard_consult_detail']            = 'Список открыток';
+$lang['piwecard_list']                        = 'Посланные открытки';
+$lang['piwecard_delete_all']                = 'Удалить все просроченные открытки?';
 $lang['valid']                            = 'Свежие';
 $lang['total']                            = 'Всего';
-$lang['ecard_force_delete']                = 'Удалить эту открытку?';
-$lang['ecard_delete']                    = 'Удалить эту открытку?';
+$lang['piwecard_force_delete']                = 'Удалить эту открытку?';
+$lang['piwecard_delete']                    = 'Удалить эту открытку?';
 
-$lang['ecard_admin_submit']                = 'Сохранить';
-$lang['ecard_default_mail']                = 'Адрес e-mail по умолчанию для пользователя Гость';
+$lang['piwecard_admin_submit']                = 'Сохранить';
+$lang['piwecard_default_mail']                = 'Адрес e-mail по умолчанию для пользователя Гость';
 
 ?>
@@ -1,5 +1,5 @@
 <?php
 /*
- * Plugin Name: Piwecard
+ * Plugin Name: Piwpiwecard
  * File :  plugin.lang.php
 * Lang : RU
Index: /extensions/Piwecard/language/sv_SE/plugin.lang.php
===================================================================
--- /extensions/Piwecard/language/sv_SE/plugin.lang.php	(revision 20091)
+++ /extensions/Piwecard/language/sv_SE/plugin.lang.php	(revision 20092)
@@ -1,5 +1,5 @@
 <?php
 /*
  * Plugin Name: Piwecard
  * File :  plugin.lang.php
 * Lang : SE 
@@ -7,74 +7,74 @@
 
 
-$lang['ecard']                            = 'Piwecard';
-$lang['ecard_infos']                     = 'E-kort beskrivning';
-$lang['ecard_from']                        = 'Från';
-$lang['ecard_to']                        = 'Till';
+$lang['piwecard']                            = 'Piwpiwecard';
+$lang['piwecard_infos']                     = 'E-kort beskrivning';
+$lang['piwecard_from']                        = 'Från';
+$lang['piwecard_to']                        = 'Till';
 
 
 
 // ecart.tpl
-$lang['ecard_send']                        = 'Skicka';
-$lang['ecard_cancel']                    = 'Avbryt';
-$lang['ecard_activ_choice']                = 'Giltighetstid';
-$lang['ecard_send_method']                = 'Sändalternativ';
-$lang['ecard_maillink']                    = 'E-post med länk';
-$lang['ecard_mailhtml']                    = 'E-post med bild';
-$lang['ecard_send_copy']                = 'Skicka kopia';
+$lang['piwecard_send']                        = 'Skicka';
+$lang['piwecard_cancel']                    = 'Avbryt';
+$lang['piwecard_activ_choice']                = 'Giltighetstid';
+$lang['piwecard_send_method']                = 'Sändalternativ';
+$lang['piwecard_maillink']                    = 'E-post med länk';
+$lang['piwecard_mailhtml']                    = 'E-post med bild';
+$lang['piwecard_send_copy']                = 'Skicka kopia';
 
 
-$lang['ecard_send_stage1']                = 'Steg 1 : Skriv ditt meddelande';
-$lang['ecard_send_stage2']                = 'Steg 2 : Ange information';
-$lang['ecard_send_stage3']                = 'Steg 3 : Alternativ';
-$lang['ecard_send_stage4']                = 'Steg 4 : Skicka e-kortet !';
+$lang['piwecard_send_stage1']                = 'Steg 1 : Skriv ditt meddelande';
+$lang['piwecard_send_stage2']                = 'Steg 2 : Ange information';
+$lang['piwecard_send_stage3']                = 'Steg 3 : Alternativ';
+$lang['piwecard_send_stage4']                = 'Steg 4 : Skicka e-kortet !';
 
-$lang['ecard_send_title']                = 'Titel ';
-$lang['ecard_send_message']                = 'Meddelande';
-$lang['ecard_send_exp']                    = 'Avsändare';
-$lang['ecard_send_dest']                = 'Mottagare';
-$lang['ecard_send_link1']                = 'För att skicka ett e-kort';
-$lang['ecard_send_link2']                = 'Klicka här';
-$lang['ecard_send_link3']                = 'Skapar ditt personliga e-kort';
+$lang['piwecard_send_title']                = 'Titel ';
+$lang['piwecard_send_message']                = 'Meddelande';
+$lang['piwecard_send_exp']                    = 'Avsändare';
+$lang['piwecard_send_dest']                = 'Mottagare';
+$lang['piwecard_send_link1']                = 'För att skicka ett e-kort';
+$lang['piwecard_send_link2']                = 'Klicka här';
+$lang['piwecard_send_link3']                = 'Skapar ditt personliga e-kort';
 
-$lang['ecard_send_exp_name']            = 'Avsändarens namn';
-$lang['ecard_send_exp_mail']            = 'Avsändarens e-post';
-$lang['ecard_send_dest_name']            = 'Mottagarens namn';
-$lang['ecard_send_dest_mail']            = 'Mottagarens e-post (dest@dest.com)';
+$lang['piwecard_send_exp_name']            = 'Avsändarens namn';
+$lang['piwecard_send_exp_mail']            = 'Avsändarens e-post';
+$lang['piwecard_send_dest_name']            = 'Mottagarens namn';
+$lang['piwecard_send_dest_mail']            = 'Mottagarens e-post (dest@dest.com)';
 
 
 // publish.tpl
-$lang['ecard_invalid_ecard']            = 'Ogiltigt eller utgånget e-kort';
-$lang['ecard_publish_bottom']            = 'Detta e-kort skickades av ';
+$lang['piwecard_invalid_piwecard']            = 'Ogiltigt eller utgånget e-kort';
+$lang['piwecard_publish_bottom']            = 'Detta e-kort skickades av ';
 
 // Admin
-$lang['ecard_admin_saveOK']                = 'Inställning sparad';
+$lang['piwecard_admin_saveOK']                = 'Inställning sparad';
 
-$lang['ecard_management']                = 'Piwecard-hantering';
-$lang['ecard_manage']                    = 'Inställningar för denna funktion i galleriet';
-$lang['ecard_active_user_cat']            = 'Aktivera denna funktion endast för användare eller kategorier som tillhör användare (baserat på upphovsman eller kategorinamn)';
-$lang['ecard_active_spec_cats']            = 'Aktivera denna funktion för valda kategorier';
-$lang['ecard_active_all_cats']            = 'Aktivera denna funtion för alla kategorier';
-$lang['ecard_recursiv']                    = 'Aktivera rekursivt';
-$lang['ecard_cat']                        = 'Välj kategorier (enbart om "alla kategorier" ej är vald)';
-$lang['ecard_authorized_group']            = 'Grupparametrar';
-$lang['ecard_authorized_group_info']    = 'Inga valda ==> Tillåtet för alla användare';
-$lang['ecard_admin_manage']                    = 'Val';
+$lang['piwecard_management']                = 'Piwpiwecard-hantering';
+$lang['piwecard_manage']                    = 'Inställningar för denna funktion i galleriet';
+$lang['piwecard_active_user_cat']            = 'Aktivera denna funktion endast för användare eller kategorier som tillhör användare (baserat på upphovsman eller kategorinamn)';
+$lang['piwecard_active_spec_cats']            = 'Aktivera denna funktion för valda kategorier';
+$lang['piwecard_active_all_cats']            = 'Aktivera denna funtion för alla kategorier';
+$lang['piwecard_recursiv']                    = 'Aktivera rekursivt';
+$lang['piwecard_cat']                        = 'Välj kategorier (enbart om "alla kategorier" ej är vald)';
+$lang['piwecard_authorized_group']            = 'Grupparametrar';
+$lang['piwecard_authorized_group_info']    = 'Inga valda ==> Tillåtet för alla användare';
+$lang['piwecard_admin_manage']                    = 'Val';
 
-$lang['ecard_admin_params']                    = 'Inställningar';
-$lang['ecard_config']                    = 'Standardinställningar';
+$lang['piwecard_admin_params']                    = 'Inställningar';
+$lang['piwecard_config']                    = 'Standardinställningar';
 
-$lang['ecard_activ_nb']                    = 'Giltighetstid för e-kort i dagar (standard)';
-$lang['ecard_days']                        = 'dagar';
-$lang['ecard_nolimit']                    = 'Obegränsat';
+$lang['piwecard_activ_nb']                    = 'Giltighetstid för e-kort i dagar (standard)';
+$lang['piwecard_days']                        = 'dagar';
+$lang['piwecard_nolimit']                    = 'Obegränsat';
 
-$lang['ecard_nomodif_expmail']            = 'Tillåt avsändaren att redigera e-postmeddelandet';
-$lang['ecard_send_HTML']                = 'Tillåt att skicka e-post med bild (annars skickas enbart länk)';
-$lang['ecard_show_infos']                = 'Visa information under bilderna (titel och upphovsman)';
-$lang['ecard_admin_nb_page']            = 'Antal e-kort i listfliken';
-$lang['ecard_mail_config']                = 'Inställningar för skickad e-post';
-$lang['ecard_subject_link']                = 'Ämne för e-post';
-$lang['ecard_message_link']                = 'Meddelande sänt (e-post med länk)';
-$lang['ecard_message_html']                = 'Meddelande sänt (e-post med bild)';
-$lang['ecard_parameters']            =
+$lang['piwecard_nomodif_expmail']            = 'Tillåt avsändaren att redigera e-postmeddelandet';
+$lang['piwecard_send_HTML']                = 'Tillåt att skicka e-post med bild (annars skickas enbart länk)';
+$lang['piwecard_show_infos']                = 'Visa information under bilderna (titel och upphovsman)';
+$lang['piwecard_admin_nb_page']            = 'Antal e-kort i listfliken';
+$lang['piwecard_mail_config']                = 'Inställningar för skickad e-post';
+$lang['piwecard_subject_link']                = 'Ämne för e-post';
+$lang['piwecard_message_link']                = 'Meddelande sänt (e-post med länk)';
+$lang['piwecard_message_html']                = 'Meddelande sänt (e-post med bild)';
+$lang['piwecard_parameters']            =
 '<b><u>Paramètres </u></b>:<br>
 <b>%yourname%</b>    ==> Sender name<br>
@@ -84,22 +84,22 @@
 <b>%website%</b>        ==> Site Name (Piwigo standard config)<br>
 <b>%websiteurl%</b>    ==> Site link (Piwigo standard config)<br>
-<b>%ecardurl%</b>      ==> Link to eCard page<br>
-<b>%ecardsubject%</b>       ==> eCard Subject (write by user)<br>
-<b>%ecardmessage%</b>     ==> eCard Message (write by user)<br>
+<b>%piwecardurl%</b>      ==> Link to piwecard page<br>
+<b>%piwecardsubject%</b>       ==> piwecard Subject (write by user)<br>
+<b>%piwecardmessage%</b>     ==> piwecard Message (write by user)<br>
 <b>%pictureurl%</b>      ==> Link to photo<br>
 <b>%pictureinfos%</b>    ==> Photo Informations (name and author)';
 
-$lang['ecard_admin_consult']                    = 'Listningar';
-$lang['ecard_consult_detail']            = 'Lista med e-kort';
-$lang['ecard_list']                        = 'Lista över sända e-kort';
-$lang['ecard_delete_all']                = 'Radera alla utgångna e-kort?';
+$lang['piwecard_admin_consult']                    = 'Listningar';
+$lang['piwecard_consult_detail']            = 'Lista med e-kort';
+$lang['piwecard_list']                        = 'Lista över sända e-kort';
+$lang['piwecard_delete_all']                = 'Radera alla utgångna e-kort?';
 $lang['valid']                            = 'Giltiga';
 $lang['total']                            = 'Alla';
-$lang['ecard_force_delete']                = 'Radera (tvingad) detta e-kort?';
-$lang['ecard_delete']                    = 'Radera detta e-kort?';
+$lang['piwecard_force_delete']                = 'Radera (tvingad) detta e-kort?';
+$lang['piwecard_delete']                    = 'Radera detta e-kort?';
 
-$lang['ecard_admin_submit']                = 'Spara';
+$lang['piwecard_admin_submit']                = 'Spara';
 
-$lang['ecard_default_mail']                = 'Standard e-post för gästkort';
+$lang['piwecard_default_mail']                = 'Standard e-post för gästkort';
 
 ?>
@@ -1,5 +1,5 @@
 <?php
 /*
- * Plugin Name: Piwecard
+ * Plugin Name: Piwpiwecard
  * File :  plugin.lang.php
 * Lang : SE 